@@ -1,22 +1,17 @@
-/*
- * Written by Solar Designer and placed in the public domain.
- */
-
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
-void caller(void (*trampoline)(void))
+void caller(void (*trampoline)())
 {
 	puts("Attempting to call a trampoline...");
 
 	trampoline();
 }
 
-void do_trampoline(void)
+void do_trampoline()
 {
-	void nested(void)
+	void nested()
 	{
 		puts("Succeeded.");
 	}
@@ -24,7 +19,7 @@ void do_trampoline(void)
 	caller(nested);
 }
 
-void do_exploit(void)
+void do_exploit()
 {
 	puts("Attempting to simulate a buffer overflow exploit...");
 
